@@ -18,7 +18,8 @@ class Mem(Widget):
         # check which mem sections are available on the machine
         self.attrs = []
         mem = psutil.virtual_memory()
-        for attr in ["used", "available", "cached", "free"]:
+        self.colors = ["yellow", "green", "blue", "magenta"]
+        for attr in ["free", "available", "cached", "used"]:
             if hasattr(mem, attr):
                 self.attrs.append(attr)
 
@@ -58,7 +59,7 @@ class Mem(Widget):
         table = Table(box=None, expand=True, padding=0, show_header=False)
         table.add_column(justify="left", no_wrap=True)
         for k, graph in enumerate(graphs):
-            table.add_row(f"[color({k + 2})]{graph}[/]")
+            table.add_row(f"[{self.colors[k]}]{graph}[/]")
 
         self.panel = Panel(
             table,
@@ -80,12 +81,12 @@ class Mem(Widget):
             ms.reset_width(event.width - 4)
 
         # split the available event.height-2 into n even blocks, and if there's
-        # a rest, divide it up into the first, e.g., with n=4
-        # 17 -> 5, 4, 4, 4
+        # a rest, divide it up into the last, e.g., with n=4
+        # 17 -> 4, 4, 4, 5
         n = len(self.attrs)
         heights = [(event.height - 2) // n] * n
         for k in range((event.height - 2) % n):
-            heights[k] += 1
+            heights[-(k + 1)] += 1
 
         for ms, h in zip(self.mem_streams, heights):
             ms.reset_height(h)
